@@ -19,10 +19,9 @@ def new(c):
 
 @task
 def tag(c):
-    f = io.StringIO()
-    c.run("git rev-parse --abbrev-ref HEAD", out_stream=f)
-    branch = f.getvalue().strip()
-    f.close()
+    with io.StringIO() as f:
+        c.run("git rev-parse --abbrev-ref HEAD", out_stream=f)
+        branch = f.getvalue().strip()
 
     if branch not in ["master", "main"]:
         print("only master/main branch can be tagged")
@@ -40,9 +39,9 @@ def tag(c):
     with open(f"docs_config/release_notes/{tag_version}.rst", "w") as fp:
         fp.write(f"{tag_version}\n------\n\n" + notes)
     build(c)
-    c.run("git add docs")
+    c.run("git add docs docs_config")
     c.run(f'git commit -m "for {tag_version}"')
     c.run(f"git tag -a {tag_version} -m '{notes}'")
     with open(current_release_path, "w") as fp:
-        fp.write("- points of whats new")
+        fp.write("")
     c.run("git push --tags")
